@@ -1,5 +1,5 @@
 from datetime import timedelta
-from typing import Union
+from typing import Any, Optional, Union
 
 import pydantic
 
@@ -16,27 +16,26 @@ from classiq_interface.backend.quantum_backend_providers import (
 
 
 class BackendPreferences(pydantic.BaseModel):
+    # Due to the way the field is currently implemented, i.e. it redefined with different types
+    # in the subclass, it shouldn't be dumped with exclude_*. This causes this field not to appear.
+    # For example: don't use obj.dict(exclude_unset=True).
     backend_service_provider: str = pydantic.Field(
-        description="Provider company for the requested backend."
+        ..., description="Provider company or cloud for the requested backend."
+    )
+    backend_name: str = pydantic.Field(
+        ..., description="Name of the requested backend or target."
     )
-    backend_name: str = pydantic.Field(description="Name of the requested backend.")
 
 
-AWS_DEFAULT_JOB_TIMEOUT_SECONDS = timedelta(minutes=5).total_seconds()
+AWS_DEFAULT_JOB_TIMEOUT_SECONDS = int(timedelta(minutes=5).total_seconds())
 
 
 class AwsBackendPreferences(BackendPreferences):
     backend_service_provider: ProviderTypeVendor.AWS_BRAKET = ProviderVendor.AWS_BRAKET
     # Allow running any backend supported by the vendor
     backend_name: Union[AWSBackendNames, str]
-    aws_access_key_id: pydantic_backend.pydanticAWSAccessKeyID = pydantic.Field(
-        description="AWS Access Key ID"
-    )
-    aws_secret_access_key: pydantic_backend.pydanticAWSSecretAccessKey = pydantic.Field(
-        description="AWS Secret Access Key"
-    )
-    region_name: pydantic_backend.pydanticRegionName = pydantic.Field(
-        description="AWS Region name"
+    aws_role_arn: pydantic_backend.pydanticAwsRoleArn = pydantic.Field(
+        description="ARN of the role to be assumed for execution on your Braket account."
     )
     s3_bucket_name: pydantic_backend.pydanticS3BucketName = pydantic.Field(
         description="S3 Bucket Name"
@@ -50,9 +49,23 @@ class AwsBackendPreferences(BackendPreferences):
     )
 
 
+class IBMBackendProvider(pydantic.BaseModel):
+    hub: Optional[str] = None
+    group: Optional[str] = None
+    project: Optional[str] = None
+
+
 class IBMBackendPreferences(BackendPreferences):
     backend_service_provider: ProviderTypeVendor.IBMQ = ProviderVendor.IBMQ
-    backend_name: IBMQBackendNames
+    backend_name: Union[IBMQBackendNames, str]
+    access_token: Optional[str] = pydantic.Field(
+        default=None,
+        description="IBMQ access token to be used with IBMQ hosted backends",
+    )
+    provider: IBMBackendProvider = pydantic.Field(
+        default_factory=IBMBackendProvider,
+        description="Provider specs. for identifying a single IBMQ provider.",
+    )
 
 
 class AzureCredential(pydantic.BaseSettings):
@@ -100,3 +113,27 @@ class IonqBackendPreferences(BackendPreferences):
 
 def is_exact_simulator(backend_preferences: BackendPreferences):
     return backend_preferences.backend_name in EXACT_SIMULATORS
+
+
+def default_backend_preferences(
+    backend_name: str = IBMQBackendNames.IBMQ_AER_SIMULATOR,
+) -> BackendPreferences:
+    return IBMBackendPreferences(backend_name=backend_name)
+
+
+def backend_preferences_field(
+    backend_name: str = IBMQBackendNames.IBMQ_AER_SIMULATOR,
+) -> Any:
+    return pydantic.Field(
+        default_factory=lambda: default_backend_preferences(backend_name),
+        description="Preferences for the requested backend to run the quantum circuit.",
+        discriminator="backend_service_provider",
+    )
+
+
+BackendPreferencesTypes = Union[
+    AzureBackendPreferences,
+    IBMBackendPreferences,
+    AwsBackendPreferences,
+    IonqBackendPreferences,
+]
