@@ -10,10 +10,8 @@ INVALID_API_KEY: str = _IONQ_API_KEY_LENGTH * "a"
 MAX_EXECUTION_TIMEOUT_SECONDS = timedelta(hours=4).total_seconds()
 
 if TYPE_CHECKING:
-    pydanticAWSAccessKeyID = str
-    pydanticAWSSecretAccessKey = str
     pydanticExecutionTimeout = int
-    pydanticRegionName = str
+    pydanticAwsRoleArn = str
     pydanticS3BucketKey = str
     pydanticS3BucketName = str
     pydanticAzureResourceIDType = str
@@ -22,22 +20,10 @@ if TYPE_CHECKING:
 else:
     # TODO Simplify regular expressions in this file
 
-    pydanticAWSAccessKeyID = pydantic.constr(
+    pydanticAwsRoleArn = pydantic.constr(
         strip_whitespace=True,
-        min_length=20,
-        max_length=20,
-        regex=r"(?<![A-Z0-9])[A-Z0-9]{20}(?![A-Z0-9])",
     )
 
-    pydanticAWSSecretAccessKey = pydantic.constr(
-        strip_whitespace=True,
-        min_length=40,
-        max_length=40,
-        regex=r"(?<![A-Za-z0-9/+=])[A-Za-z0-9/+=]{40}(?![A-Za-z0-9/+=])",
-    )
-
-    pydanticRegionName = pydantic.constr(strip_whitespace=True, min_length=1)
-
     pydanticS3BucketName = pydantic.constr(strip_whitespace=True, min_length=3)
 
     pydanticS3BucketKey = pydantic.constr(strip_whitespace=True, min_length=1)
