@@ -1,5 +1,6 @@
 from enum import Enum
-from typing import Literal
+
+from typing_extensions import Literal
 
 
 class ProviderVendor(str, Enum):
@@ -49,7 +50,7 @@ class IBMQBackendNames(str, Enum):
     IBMQ_AER_SIMULATOR_MATRIX_PRODUCT_STATE = "aer_simulator_matrix_product_state"
 
 
-EXACT_SIMULATORS = [
+EXACT_SIMULATORS = {
     IonqBackendNames.SIMULATOR,
     AzureQuantumBackendNames.IONQ_SIMULATOR,
     AzureQuantumBackendNames.MICROSOFT_FULLSTATE_SIMULATOR,
@@ -57,4 +58,4 @@ EXACT_SIMULATORS = [
     AWSBackendNames.AWS_BRAKET_TN1,
     AWSBackendNames.AWS_BRAKET_DM1,
     *IBMQBackendNames,
-]
+}
