@@ -1,9 +1,12 @@
 import pydantic
 
 from classiq_interface.combinatorial_optimization.solver_types import QSolver
+from classiq_interface.generator.model.constraints import Constraints
+from classiq_interface.generator.model.model import BackwardsCompatibleBaseModel
+from classiq_interface.generator.model.preferences.preferences import Preferences
 
 
-class QAOAPreferences(pydantic.BaseModel):
+class QAOAPreferences(BackwardsCompatibleBaseModel):
     qsolver: QSolver = pydantic.Field(
         default=QSolver.QAOAPenalty,
         description="Indicates whether to use QAOA with penalty terms or constrained QAOA.",
@@ -17,6 +20,9 @@ class QAOAPreferences(pydantic.BaseModel):
         "the converges rate. Small positive values are preferred",
     )
 
+    constraints: Constraints = pydantic.Field(default_factory=Constraints)
+    preferences: Preferences = pydantic.Field(default_factory=Preferences)
+
     @pydantic.validator("penalty_energy", pre=True, always=True)
     def check_penalty_energy(cls, penalty_energy, values):
         qsolver = values.get("qsolver")
