@@ -4,14 +4,13 @@ from typing import List, Optional, Union
 import pydantic
 
 from classiq_interface.backend.backend_preferences import (
-    AwsBackendPreferences,
-    AzureBackendPreferences,
-    IBMBackendPreferences,
-    IonqBackendPreferences,
+    BackendPreferencesTypes,
+    backend_preferences_field,
 )
+from classiq_interface.backend.quantum_backend_providers import IBMQBackendNames
 from classiq_interface.executor.error_mitigation import ErrorMitigationMethod
+from classiq_interface.generator.model.preferences.randomness import create_random_seed
 from classiq_interface.generator.noise_properties import NoiseProperties
-from classiq_interface.generator.preferences.randomness import create_random_seed
 from classiq_interface.helpers.custom_pydantic_types import (
     pydanticAlphaParamCVAR,
     pydanticProbabilityFloat,
@@ -26,11 +25,12 @@ class AmplitudeEstimation(pydantic.BaseModel):
         default=0.01, description="precision for estimation target `a`"
     )
     binary_search_threshold: Optional[pydanticProbabilityFloat] = pydantic.Field(
-        description="The required probability on the tail of the distribution (1 - percentile)"
+        default=None,
+        description="The required probability on the tail of the distribution (1 - percentile)",
     )
 
     objective_qubits: List[int] = pydantic.Field(
-        default=[],
+        default_factory=list,
         description="list specifying on which qubits to perform the amplitude estimation",
     )
 
@@ -156,9 +156,18 @@ class ExecutionPreferences(pydantic.BaseModel):
         description="If set, limits the execution runtime. Value is in seconds. "
         "Not supported on all platforms.",
     )
-    amplitude_estimation: Optional[AmplitudeEstimation]
-    amplitude_amplification: Optional[AmplitudeAmplification]
-    vqe_optimization: Optional[VQEOptimization]
+    amplitude_estimation: Optional[AmplitudeEstimation] = pydantic.Field(
+        default=None,
+        description="Settings related to amplitude estimation execution, used during the finance execution.",
+    )
+    amplitude_amplification: AmplitudeAmplification = pydantic.Field(
+        default_factory=AmplitudeAmplification,
+        description="Settings related to amplitude amplification execution, used during the grover execution.",
+    )
+    vqe_optimization: VQEOptimization = pydantic.Field(
+        default_factory=VQEOptimization,
+        description="Settings related to VQE execution.",
+    )
     error_mitigation_method: Optional[ErrorMitigationMethod] = pydantic.Field(
         default=None,
         description="Error mitigation method. Currently supports complete and tensored "
@@ -171,14 +180,6 @@ class ExecutionPreferences(pydantic.BaseModel):
         default_factory=create_random_seed,
         description="The random seed used for the generation",
     )
-    backend_preferences: Union[
-        AzureBackendPreferences,
-        IBMBackendPreferences,
-        AwsBackendPreferences,
-        IonqBackendPreferences,
-    ] = pydantic.Field(
-        default_factory=lambda: IBMBackendPreferences(
-            backend_service_provider="IBMQ", backend_name="aer_simulator_statevector"
-        ),
-        description="Preferences for the requested backend to run the quantum circuit.",
+    backend_preferences: BackendPreferencesTypes = backend_preferences_field(
+        backend_name=IBMQBackendNames.IBMQ_AER_SIMULATOR_STATEVECTOR
     )
