@@ -3,7 +3,7 @@ from typing import Any, Dict, Optional, Union
 
 import pydantic
 
-from classiq_interface.hybrid.result import VQESolverResult
+from classiq_interface.executor.vqe_result import SolverResult, VQESolverResult
 
 
 class ExecutionStatus(str, enum.Enum):
@@ -55,6 +55,7 @@ ExecutionData = Union[
     FinanceSimulationResults,
     GroverSimulationResults,
     VQESolverResult,
+    SolverResult,
     str,
 ]
 
