@@ -9,5 +9,5 @@ def get_rand_adjacency_matrix(num_vertices: int) -> List[List[bool]]:
         for j in range(num_vertices):
             if i > j:
                 adjacency_matrix[i, j] = adjacency_matrix[j, i]
-    adjacency_matrix -= np.diag(np.diag(adjacency_matrix))  # type: ignore[no-untyped-call]
+    adjacency_matrix -= np.diag(np.diag(adjacency_matrix))
     return adjacency_matrix.tolist()
