@@ -1,12 +1,26 @@
+import enum
 from typing import Dict, List, Optional, Union
 
 import pydantic
 
-from classiq_interface.hybrid.mht_input import (
-    EntanglementBlocksType,
-    EntanglementStructureType,
-    RotationBlocksType,
-)
+
+class RotationBlocksType(str, enum.Enum):
+    rx = "rx"
+    ry = "ry"
+    rz = "rz"
+
+
+class EntanglementBlocksType(str, enum.Enum):
+    cx = "cx"
+    cy = "cy"
+    cz = "cz"
+
+
+class EntanglementStructureType(str, enum.Enum):
+    linear = "linear"
+    full = "full"
+    circular = "circular"
+    sca = "sca"
 
 
 class CustomAnsatzArgs(pydantic.BaseModel):
