@@ -1,5 +1,4 @@
-from enum import Enum
-from typing import Dict, Optional
+from typing import Optional
 
 import pydantic
 
@@ -14,20 +13,18 @@ from classiq_interface.generator.function_params import FunctionParams
 class UnaryOpParams(FunctionParams):
     arg: RegisterUserInput
     output_size: Optional[pydantic.PositiveInt]
-    output_name: Optional[str]
+    output_name: Optional[str] = DEFAULT_OUT_NAME
     inplace: bool = False
 
-    def create_io_enums(self):
-        output_name = self.output_name if self.output_name else DEFAULT_OUT_NAME
+    def _create_io_names(self):
+        output_names = [self.output_name if self.output_name else DEFAULT_OUT_NAME]
         arg_name = self.arg.name if self.arg.name else DEFAULT_ARG_NAME
 
-        output_name_dict: Dict[str, str] = {output_name: output_name}
-        input_name_dict = {arg_name: arg_name}
         if not self.inplace:
-            output_name_dict.update(input_name_dict)
+            output_names.append(arg_name)
 
-        self._output_enum = Enum("BinaryOpOutputs", output_name_dict)
-        self._input_enum = Enum("UnaryOpInputs", input_name_dict)
+        self._output_names = output_names
+        self._input_names = [arg_name]
 
     class Config:
         arbitrary_types_allowed = True
