@@ -7,7 +7,7 @@ import numpy as np
 
 
 def _distance_between_points(point_1: np.ndarray, point_2: np.ndarray) -> float:
-    return np.linalg.norm(point_1 - point_2)  # type: ignore[no-untyped-call]
+    return float(np.linalg.norm(point_1 - point_2))
 
 
 def get_distance_matrix(cities: np.ndarray) -> List[List[float]]:
@@ -31,5 +31,5 @@ def get_rand_distance_matrix(num_points: int) -> List[List[float]]:
     distance_matrix = np.random.rand(num_points, num_points)
     distance_matrix *= 0.5
     distance_matrix += distance_matrix.T
-    distance_matrix -= np.diag(np.diag(distance_matrix))  # type: ignore[no-untyped-call]
+    distance_matrix -= np.diag(np.diag(distance_matrix))
     return distance_matrix.tolist()
