@@ -75,12 +75,8 @@ class FunctionData(pydantic.BaseModel):
     def _deduce_composite_io_names(
         logic_flow: List[function_call.FunctionCall],
     ) -> Tuple[Set[str], Set[str]]:
-        input_wires = list(
-            chain(*[call.inputs.values() for call in logic_flow if call.inputs])
-        )
-        output_wires = list(
-            chain(*[call.outputs.values() for call in logic_flow if call.outputs])
-        )
+        input_wires = list(chain(*(call.non_zero_input_wires for call in logic_flow)))
+        output_wires = list(chain(*(call.non_zero_output_wires for call in logic_flow)))
 
         input_names = {name for name in input_wires if name not in output_wires}
         output_names = {name for name in output_wires if name not in input_wires}
