@@ -8,6 +8,9 @@ from classiq_interface.generator import function_params
 
 
 class HardwareEfficientAnsatz(function_params.FunctionParams):
+    _input_names = pydantic.PrivateAttr(default=[function_params.DEFAULT_INPUT_NAME])
+    _output_names = pydantic.PrivateAttr(default=[function_params.DEFAULT_OUTPUT_NAME])
+
     num_qubits: pydantic.PositiveInt = pydantic.Field(
         description="Number of qubits in the ansatz"
     )
