@@ -1,18 +1,10 @@
-from enum import Enum
-from typing import Type
+from typing import List
 
 import pydantic
 
 from classiq_interface.generator import function_params
 
 
-class QftInputs(Enum):
-    IN = "IN"
-
-
-QftOutputs = function_params.DefaultOutputNames
-
-
 class QFT(function_params.FunctionParams):
     """
     Creates a quantum Fourier transform on a specified number of qubits.
@@ -22,7 +14,7 @@ class QFT(function_params.FunctionParams):
     num_qubits: pydantic.PositiveInt = pydantic.Field(
         description="The number of qubits on which the QFT acts."
     )
-    approximation_degree: pydantic.conint(ge=0) = pydantic.Field(
+    approximation_degree: pydantic.NonNegativeInt = pydantic.Field(
         default=0,
         description="The degree of approximation (0 for no approximation). The smallest "
         "'approximation_degree' rotation angles are dropped from the QFT.",
@@ -35,5 +27,5 @@ class QFT(function_params.FunctionParams):
         description="If True, the inverse Fourier transform is constructed.",
     )
 
-    _input_names: Type[Enum] = pydantic.PrivateAttr(default=QftInputs)
-    _output_names: Type[Enum] = pydantic.PrivateAttr(default=QftOutputs)
+    _input_names: List[str] = pydantic.PrivateAttr(default=["IN"])
+    _output_names: List[str] = pydantic.PrivateAttr(default=["OUT"])
